#!/usr/bin/env python

import sys
from sklearn.feature_extraction.text import CountVectorizer
from sklearn.metrics.pairwise import cosine_similarity
import matplotlib.pyplot as plt

def cal_similarity(corpus):
    vectorizer = CountVectorizer()
    X = vectorizer.fit_transform(corpus)
    return cosine_similarity(X)

def viz(simi_matrix, save_path):
    n = simi_matrix.shape[0]
    for i in range(n):
        for j in range(n):
            plt.text(
                i, j,
                "%5.3f" % simi_matrix[i, j],
                verticalalignment="center",
                horizontalalignment="center",
            )
    plt.imshow(simi_matrix)
    plt.colorbar()
    plt.title("Similarity between sentences")
    plt.xticks(range(n))
    plt.yticks(range(n))
    plt.savefig(save_path)


if __name__ == '__main__':
    with open(sys.argv[1], 'r') as f:
        corpus = f.read().splitlines()
    simi_matrix = cal_similarity(corpus)
    viz(simi_matrix, save_path='ex2_stage2_output.png')